#ifndef LCD_MENU_H
#define LCD_MENU_H

/*
** Copyright (C) 2007 felix <felixmatenaar@web.de>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "lcd.h"

//**********************
// dont forget to set them to the number of pages you defined
#define NUM_PAGES 1
//**********************
/*
 * The Page struct stores everything 
 * you need to manage a page
 */
typedef struct Page fPage;

typedef struct
{
	// ASCII string which is showd on the lcdscreen
	char	 line[LCD_LINES][LCD_DISP_LENGTH]; 

	// the number of funtions you ve bound to a page
  uint8_t  num_actions;

	// the current action which is selected by the cursor
	int8_t   cur_action;

	// stores the x position of every "button" (function)
  uint8_t* act_pos_x;

	// stores the y position of every "button" (function)
	uint8_t* act_pos_y;

	// stores the addresses of the functions bound to the page buttons
	int8_t   (**p_acts)(fPage*);
} Page;


/*
 * Function takes a page id and prints its
 * lines on the lcdscreen
 * returns 1 on success
 */
int8_t  page_display(uint8_t new_page);

/*
 * Function takes a page to copy
 * the given strings in it.
 * works similar to a strcpy.
 * returns 0 on success 
 *		or	-1 on error
 */
int8_t  page_init_screen(Page* page,char* lines []);

/*
 * Function takes a Page
 * and allocates memory for
 * num_actions actions
 */
void    page_reserve(Page* page, uint8_t num_actions);

/*
 * Function takes the given functionpointer,
 * attaches it to page and binds it on the 
 * given coordinates act_pos_x/y
 */
int8_t  page_add_action(Page* page, uint8_t act_pos_x, uint8_t act_pos_y, int8_t(*)(Page*),uint8_t);

#endif

