#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <avr/pgmspace.h>

#include "lcd.h"
#include "lcdmenu.h"

#define LCD_LINES 2
#define LCD_DISP_LENGT

/************************************************************
// IMPORTANT: READ THIS FILE BEFORE USING THE LCDMENU LIBRARY!
************************************************************/

/*
	The lcdmenu library is for making it easier to create 
  pages with buttons on a lcd display. To do this you
  have to write functions for each page which either 
  do initialization or implement functionality to a specific
  coordinate. See also lcdmenu.h and the comments in main() 
  for a description of each function. This library will only
	handle pages. For CONFIGURING YOUR LCD DISPLAY look into
  lcd.h and lcd.c
*/

#define PAGE_EXAMPLE 0

extern uint8_t cur_page;
extern Page *menu_pages;

#define CUR_ID(__x) __x->cur_action
#if NUM_PAGES < 1
#error "You have to set NUM_PAGES to the number of pages you created (at least 1) !"
#endif


//// ACTION FUNCTIONS ////
/*
 *	The functions below will handle user input.
 *  in our example we ve got three buttons,
 *  two for directions and one for selecting an
 *  option
 */

/*
 * Function will be called when
 * select button is pressed.
 */
void
page_button(Page* page)
//{{{
{
	//call function which is bound to the selected coordinates
  page->p_acts[page->cur_action]((void*)(page));
}
//}}}

// END OF ACTION FUNCTIONS


///// EXAMPLE PAGE FUNCTIONS

int8_t
page_example_add(Page* page)
//{{{
{
	// increases digit and sets it to 0 after 9
	//char *digit = (page.line)[1][1];//[page->act_pos_y[CUR_ID(page)]][page->act_pos_x[CUR_ID(page)]]; 
	char*digit;
	(*digit)++;
	*digit-='0';
	if(*digit>9);
		*digit=0;
	*digit+='0';
	
	page_display(PAGE_EXAMPLE);	
	
	return 0;
}
//}}}

int8_t
page_example_init(Page* page)
//{{{
{
  const uint8_t num_actions = 1;
	char lines[LCD_LINES][LCD_DISP_LENGTH+1];
	
  strncpy(lines[0],PSTR("EXAMPLE PAGE!"),LCD_DISP_LENGTH+1);
  strncpy(lines[1],PSTR("EXAMPLE PAGE!"),LCD_DISP_LENGTH+1);

	// copies lines to page buffer
	page_init_screen(page,lines);

	// reserves memory for one action
	page_reserve(page,num_actions);

	// adds a an action to page on x=9/ y=2 with action id 0 
	// and binds function page_example_add to it	
	page_add_action(page,9,2,page_example_add,0);

	// activates cursor
  lcd_command(LCD_ON_CURSOR);

	return 0;
}
//}}}



/*
 * This function will create our defined pages.
 */
int8_t
create_pages(void)
//{{{
{
  /*
   * The memory for your pages will be allocated here
   * so "menu_pages" are all your pages
   */
   menu_pages = malloc((sizeof(Page) * NUM_PAGES));

  /* Here you can call your individual initialization function
   * for each page.
   * I recommend to call it <pagename>_page_init().
   * Don't forget to increase NUM_PAGES for each new page
   * so that more memory will be reserved.
   * Please insert your action functions into the
   * action block and give it a name like
   * <page name>_page_<action name>()
   *
  */
  
  if(page_example_init(&(menu_pages[PAGE_EXAMPLE])) == -1)
    return -1;
  
  return 0;
}
//}}}

#ifdef LCD_MENU_DESTROY
void
destroy_pages(void)
//{{{
{
  for(uint8_t i = 0; i < NUM_PAGES; i++)
  {
    if(menu_pages[i].act_pos_x != NULL)
      free((void*)(menu_pages[i].act_pos_x));

    if(menu_pages[i].act_pos_y != NULL)
      free((void*)(menu_pages[i].act_pos_y));

    if(menu_pages[i].act_pos_x != NULL)
      free((void*)(menu_pages[i].p_acts));
  }

  free((void*)menu_pages);
  cur_page = 0;
}
//}}}
#endif

int main(void)
//{{{
{
	
	DDRA=0x00;	
	uint8_t input = PINA;

	// At first we create our defined example page (look into create_pages())
  create_pages();
	
	// writes PAGE_EXAMPLE on lcd display
	page_display(PAGE_EXAMPLE);

	while(1){
		if(input != PINA )
			page_button(&menu_pages[cur_page]);
	}	

	return 0;	
}
//}}}

/*
** Copyright (C) 2007 felix <felixmatenaar@web.de>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software 
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

